@@ -4,9 +4,9 @@ require_relative '../../lib/sass/elf'
 
 module Sass
   module CLI
-    INTERPRETER = '/lib/ld-linux-aarch64.so.1'
+    INTERPRETER = '/lib/ld-linux-armhf.so.3'
 
-    INTERPRETER_SUFFIX = '/ld-linux-aarch64.so.1'
+    INTERPRETER_SUFFIX = '/ld-linux-armhf.so.3'
 
     COMMAND = [
       *(ELF::INTERPRETER if ELF::INTERPRETER != INTERPRETER && ELF::INTERPRETER&.end_with?(INTERPRETER_SUFFIX)),
